@@ -3,6 +3,9 @@
 -- Create pgaudit extension
 CREATE EXTENSION IF NOT EXISTS pgaudit;
 
+-- Grant all on public schema to public
+GRANT ALL ON SCHEMA public TO public;
+
 -- Make sure events don't get logged twice when session logging
 SET pgaudit.log = 'all';
 SET pgaudit.log_client = ON;
@@ -297,6 +300,35 @@ UPDATE public.test4
 -- update (name) takes precedence over select (name) due to ordering
 update public.test4 set name = 'foo' where name = 'bar';
 
+--
+-- Confirm that "long" parameter values will not be logged if pgaudit.log_parameter_max_size
+-- is set.
+\connect - :current_user
+ALTER ROLE user2 SET pgaudit.log_parameter_max_size = 50;
+ALTER ROLE user2 SET pgaudit.log_parameter = 'on';
+
+\connect - user2
+PREPARE testinsert(int, text) AS
+    INSERT INTO test4 VALUES($1, $2);
+
+EXECUTE testinsert(1, '*******************************************************');
+
+DEALLOCATE testinsert;
+
+\connect - :current_user
+ALTER ROLE user2 RESET pgaudit.log_parameter_max_size;
+
+\connect - user2
+PREPARE testinsert(int, text) AS
+    INSERT INTO test4 VALUES($1, $2);
+
+EXECUTE testinsert(2, '*******************************************************');
+
+DEALLOCATE testinsert;
+
+\connect - :current_user
+ALTER ROLE user2 RESET pgaudit.log_parameter;
+
 --
 -- Change permissions of user 1 so that session logging will be done
 \connect - :current_user
@@ -607,8 +639,7 @@ DO $$
 DECLARE
 	table_name TEXT = 'do_table';
 BEGIN
-	EXECUTE 'CREATE TABLE ' || table_name || ' ("weird name" INT)';
-	EXECUTE 'DROP table ' || table_name;
+	EXECUTE E'\t\n\r CREATE TABLE ' || table_name || E' ("weird name" INT)\t\n\r ; DROP table ' || table_name;
 END $$;
 
 --
@@ -1583,11 +1614,22 @@ SET pgaudit.log = 'all,-misc_set';
 SET pgaudit.log_level = 'warning';
 
 CREATE EXTENSION pg_stat_statements;
-ALTER EXTENSION pg_stat_statements UPDATE TO '1.9';
+ALTER EXTENSION pg_stat_statements UPDATE TO '1.11';
 DROP EXTENSION pg_stat_statements;
 
 SET pgaudit.log_level = 'notice';
 
+-- Check that password redaction works with CREATE/ALTER USER MAPPING
+CREATE EXTENSION postgres_fdw;
+CREATE SERVER fdw_server FOREIGN DATA WRAPPER postgres_fdw OPTIONS (host 'foo', dbname 'foodb', port '5432');
+
+CREATE USER MAPPING FOR user1 SERVER fdw_server OPTIONS (user 'user1', password 'secret');
+ALTER USER MAPPING FOR user1 SERVER fdw_server OPTIONS (SET /* comment */ password 'secret2');
+
+DROP USER MAPPING FOR user1 SERVER fdw_server;
+DROP SERVER fdw_server;
+DROP EXTENSION postgres_fdw;
+
 -- Cleanup
 -- Set client_min_messages up to warning to avoid noise
 SET client_min_messages = 'warning';
@@ -1597,6 +1639,7 @@ ALTER ROLE :current_user RESET pgaudit.log_catalog;
 ALTER ROLE :current_user RESET pgaudit.log_client;
 ALTER ROLE :current_user RESET pgaudit.log_level;
 ALTER ROLE :current_user RESET pgaudit.log_parameter;
+ALTER ROLE :current_user RESET pgaudit.log_parameter_max_size;
 ALTER ROLE :current_user RESET pgaudit.log_relation;
 ALTER ROLE :current_user RESET pgaudit.log_statement;
 ALTER ROLE :current_user RESET pgaudit.log_statement_once;
@@ -1606,6 +1649,7 @@ RESET pgaudit.log;
 RESET pgaudit.log_catalog;
 RESET pgaudit.log_level;
 RESET pgaudit.log_parameter;
+RESET pgaudit.log_parameter_max_size;
 RESET pgaudit.log_relation;
 RESET pgaudit.log_statement;
 RESET pgaudit.log_statement_once;
